package
Version:
v0.0.0-...-659ce9b
Opens a new window with list of versions in this module.
Published: Jan 7, 2018
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Enum interface {
Next() (item Item, has bool)
Close()
}
type Item interface {
Error() error
Value() interface{}
ID() string
Range(n int) Range
Delete()
Set(v interface{}) error
}
type Range struct {
Min, Max uint64
}
func (a *Range) MaximizeIfZeroMax()
Source Files
¶
Click to show internal directories.
Click to hide internal directories.